# ISO 6346 Freight Containers: Coding, Identification and Marking

## Synopsis

CSC owner codes.

The calculation is based upon:

 * [ISO 6346:2022 Freight containers — Coding, identification and marking](https://www.iso.org/standard/83558.html)
